@@ -1,10 +1,11 @@
 # dbitem.py
 import re
 
+
 class DBItem():
 
     # Auto detect and split labels/cmd
-    def __init__(self, line):
+    def __init__(self, line, tags=None):
         label = ""
         post = re.match(r'.*(\[(.*)\])$', line)
         pre = re.match(r'^(\[(.*)\])(.*)$', line)
@@ -16,17 +17,11 @@ class DBItem():
             line = re.sub(r'^(\[(.*)\])', '', line)
         self.label = label.strip()
         self.cmd = line.strip()
+        if tags:
+            self.tags = tags[:]
+        else:
+            self.tags = []
 
     # Return a string suitable for substring searching
     def search_key(self):
-        return f"{self.label} {self.cmd}".lower()
-
-    # Return a pretty string representation
-    def pretty(self, indent=0, show_label=True):
-
-        if self.label and show_label:
-            label = self.label.ljust(indent) + " "
-        else:
-            label = ""
-
-        return f"{label}{self.cmd}"
+        return "{0} {1}".format(self.label, self.cmd).lower()
